@@ -12,7 +12,7 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "vte.h" */
+/* enumerations from "../../../src/vte.h" */
 GType vte_terminal_erase_binding_get_type (void);
 #define VTE_TYPE_TERMINAL_ERASE_BINDING (vte_terminal_erase_binding_get_type ())
 GType vte_terminal_cursor_blink_mode_get_type (void);
@@ -21,6 +21,14 @@ GType vte_terminal_cursor_shape_get_type (void);
 #define VTE_TYPE_TERMINAL_CURSOR_SHAPE (vte_terminal_cursor_shape_get_type ())
 GType vte_terminal_write_flags_get_type (void);
 #define VTE_TYPE_TERMINAL_WRITE_FLAGS (vte_terminal_write_flags_get_type ())
+
+/* enumerations from "../../../src/vtepty.h" */
+GType vte_pty_flags_get_type (void);
+#define VTE_TYPE_PTY_FLAGS (vte_pty_flags_get_type ())
+GType vte_pty_error_get_type (void);
+#define VTE_TYPE_PTY_ERROR (vte_pty_error_get_type ())
+
+/* enumerations from "../../../src/vtedeprecated.h" */
 GType vte_terminal_anti_alias_get_type (void);
 #define VTE_TYPE_TERMINAL_ANTI_ALIAS (vte_terminal_anti_alias_get_type ())
 G_END_DECLS
